@@ -1,5 +1,7 @@
 # DMT_core
-# Copyright (C) 2019  Markus Müller and Mario Krattenmacher and the DMT contributors <https://gitlab.hrz.tu-chemnitz.de/CEDIC_Bipolar/DMT/>
+# Copyright (C) from 2022  SemiMod
+# Copyright (C) until 2021  Markus Müller, Mario Krattenmacher and Pascal Kuthe
+# <https://gitlab.com/dmt-development/dmt-core>
 #
 # This file is part of DMT_core.
 #
@@ -17,16 +19,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>
 name = "Hdev"
 
-# models
-from .models.mobility import get_mobility
-from .models.mobility import get_velocity
-
 from .dut_hdev import DutHdev
 from .dut_hdev import getITRSHBT
 from .dut_hdev import hdev_iv_fallback
-
-# deprecated and will remove at some point
-# from .xsteps.x_velocity_field import XVelocityField
-# from .xsteps.x_v_intervalley import XVIntervalley
-# from .xsteps.x_coos_fit import XFitCOOS
-# from .Hdevmodel import COOSModel
