@@ -26,7 +26,7 @@ try:
 except ImportError:
     from semver import VersionInfo
 
-__version__ = VersionInfo(major=1, minor=6, patch=2)  # , prerelease="rc.1"
+__version__ = VersionInfo(major=1, minor=7, patch=0)  # , prerelease="rc.1"
 # to get the next version:
 # __version__.next_version(x) - with x = "major", "minor", "patch", "prerelease"
 
@@ -69,6 +69,7 @@ from .va_file import VAFile
 from .mcard import MCard
 from .technology import Technology
 from .circuit import Circuit, CircuitElement
+from .mc_skywater import McSkywater
 
 # plotting
 from .plot import Plot
@@ -81,7 +82,8 @@ from .plot_2yaxis import Plot2YAxis
 from .data_processor import is_iterable, flatten, strictly_increasing, DataProcessor
 
 from .data_frame import DataFrame
-from .sweep import Sweep, SweepDef, get_sweepdef
+from .sweep_def import SweepDef
+from .sweep import Sweep, get_sweepdef
 from .database_manager import DatabaseManager
 from .data_reader import (
     read_data,
