@@ -10,10 +10,12 @@ A DuT can be supplied using the input_circuit parameter. This parameter can be:
 * List with paths to netlists or strings with netlists, these will be combined into the netlist to simulate.
 
 
-Author: Mario Krattenmacher | Mario.Krattenmacher@tu-dresden.de
+Author: Mario Krattenmacher | Mario.Krattenmacher@semimod.de
 """
 # DMT_core
-# Copyright (C) 2019  Markus Müller and Mario Krattenmacher and the DMT contributors <https://gitlab.hrz.tu-chemnitz.de/CEDIC_Bipolar/DMT/>
+# Copyright (C) from 2022  SemiMod
+# Copyright (C) until 2021  Markus Müller, Mario Krattenmacher and Pascal Kuthe
+# <https://gitlab.com/dmt-development/dmt-core>
 #
 # This file is part of DMT_core.
 #
@@ -31,7 +33,7 @@ Author: Mario Krattenmacher | Mario.Krattenmacher@tu-dresden.de
 # along with this program.  If not, see <http://www.gnu.org/licenses/>
 import copy
 from collections import OrderedDict
-from DMT.core import create_md5_hash, DutView, McParameterComposition
+from DMT.core import create_md5_hash, DutView, McParameterCollection, DutType
 from DMT.core.mcard import MCard
 
 
@@ -41,7 +43,7 @@ class DutCircuit(DutView):
     Makes a circuit simulator like ADS or XYCE useable by DMT
 
     Parameters
-    -----------
+    ----------
     database_dir    : string
         This is the directory were the DUT will create its database.
     name      :  string
@@ -56,16 +58,24 @@ class DutCircuit(DutView):
 
 
     Attributes
-    -----------
+    ----------
     sim_command : str
         Command to start the correct circuit simulator
     sim_args : list[str]
         List of arguments for the simulator command, will be added one by one before the input file.
     """
 
-    def __init__(self, database_dir, name, dut_type, inp_circuit, simulator_options=None, **kwargs):
-        self._inp_header = None
-        self._modelcard = None
+    def __init__(
+        self,
+        database_dir: str,
+        name: str,
+        dut_type: DutType,
+        inp_circuit,
+        simulator_options: dict = None,
+        get_circuit_arguments: dict = None,
+        **kwargs
+    ):
+        self._inp_header = ""
 
         super().__init__(database_dir, name, dut_type, **kwargs)
 
@@ -74,8 +84,14 @@ class DutCircuit(DutView):
         else:
             self.simulator_options = OrderedDict(sorted(simulator_options.items()))
 
+        if get_circuit_arguments is None:
+            self.get_circuit_arguments = OrderedDict()
+        else:
+            self.get_circuit_arguments = OrderedDict(sorted(get_circuit_arguments.items()))
+
         # save for later use
         self._inp_circuit = None
+        self._modelcard = None
         self.inp_header = inp_circuit
 
     @property
@@ -88,7 +104,7 @@ class DutCircuit(DutView):
         """Setter method for the input header. This removes any stored data from the object, as it is not valid anymore! Automatically calls create_inp_header, if it is not a string or a list of strings.
 
         Parameters
-        -----------
+        ----------
         value : str, list[string] or valid for create_inp_header
         """
         value = copy.deepcopy(value)
@@ -110,7 +126,7 @@ class DutCircuit(DutView):
                         inp_header = inp_header + "\n" + inp_file.read()
                 except IOError:
                     # could not open input file. Assume it is already a netlist
-                    inp_header = inp_header + "\n" + value
+                    inp_header = inp_header + "\n" + netlist
 
             self._inp_header = inp_header
         else:
@@ -129,7 +145,7 @@ class DutCircuit(DutView):
         ----------
         modelcard : MCard
         """
-        if isinstance(modelcard, MCard) or isinstance(modelcard, McParameterComposition):
+        if isinstance(modelcard, MCard) or isinstance(modelcard, McParameterCollection):
             self._modelcard = modelcard
             self.inp_header = modelcard
         else:
@@ -141,18 +157,20 @@ class DutCircuit(DutView):
         Is overwritten here, to include the imported and appended files!
 
         Returns
-        --------
+        -------
         str or False
 
-        Todo
-        ----
+        Notes
+        -----
         Also account for dut.name?
         """
         if self.inp_header is None:
             return False
 
         if self._list_va_file_contents:
-            list_va = [content for (file_name, content) in self._list_va_file_contents]
+            list_va = [
+                vafile.get_tree_hash() for vafile in self._list_va_file_contents
+            ]  # directly use the hash here - hash of hash should be ok :)
         else:
             list_va = []
         return create_md5_hash(self.inp_header, *self.list_copy, *list_va)
@@ -176,7 +194,7 @@ class DutCircuit(DutView):
         """Transforms a :class:`~DMT.classes.circuit.CircuitElement` into a string fitting for the inheriting DutCircuit.
 
         Parameters
-        -----------
+        ----------
         circuit_element
             CircuitElement to transform
 
@@ -191,7 +209,7 @@ class DutCircuit(DutView):
 
     def scale_modelcard(self):
         """Scales the given modelcard to the actual size of the dut."""
-        if self.technology is None:
+        if self.technology is None or not hasattr(self.technology, "scale_modelcard"):
             self.modelcard = self.modelcard
         else:
             self.modelcard = self.technology.scale_modelcard(
