@@ -1,5 +1,7 @@
 # DMT_core
-# Copyright (C) 2019  Markus Müller and Mario Krattenmacher and the DMT contributors <https://gitlab.hrz.tu-chemnitz.de/CEDIC_Bipolar/DMT/>
+# Copyright (C) from 2022  SemiMod
+# Copyright (C) until 2021  Markus Müller, Mario Krattenmacher and Pascal Kuthe
+# <https://gitlab.com/dmt-development/dmt-core>
 #
 # This file is part of DMT_core.
 #
@@ -18,12 +20,12 @@
 import os
 import re
 import shutil
-import _pickle as cpickle
+import _pickle as cpickle  # type: ignore
 
 # import pickle as cpickle
 import copy
 import logging
-from DMT.core import DatabaseManager, read_data, DataFrame
+from DMT.core import DatabaseManager, read_data, DataFrame, VAFile
 from DMT.config import DATA_CONFIG
 from pathlib import Path
 import pandas as pd
@@ -36,10 +38,10 @@ class DutView(object):
     This ensures that all classes in DMT work independent of the concrete simulation back-end.
 
     Parameters
-    ------------
+    ----------
 
     database_dir :  str or None
-        The directory where all the databases of this project are saved. If None, DMT.config.DB_DIR is used.
+        The directory where all the databases of this project are saved. If None, DMT.config.DATA_CONFIG["directories"]["database"] is used.
     name       :  str
         The name of the DutView object, which is used as a prefix for saving the database and the pickled object.
     dut_type   : :class:`~DMT.core.dut_type.DutType`
@@ -76,7 +78,7 @@ class DutView(object):
         The name of the input file to be generated.
 
     Attributes
-    -----------
+    ----------
     database_dir :  str
         The directory where all the databases of this project are saved.
     name       :  str
@@ -104,7 +106,7 @@ class DutView(object):
         List of path or data to save to the simlation folder. If it is a path, the file is copied. If it is data, a file is created.
 
     Methods
-    --------
+    -------
     run_simulation(sweep)
         Start the simulation of this DutView object.
     prepare_simulation(sweep)
@@ -138,23 +140,25 @@ class DutView(object):
         database_dir,
         name,
         dut_type,
-        copy_va_files=False,
+        copy_va_files=True,
         force=False,
         separate_databases=False,
         list_copy=None,
         t_max=None,
         simulate_on_server=None,
-        simulator_command=None,
+        simulator_command="",
         simulator_arguments=None,
         technology=None,
         width=None,
         length=None,
         nfinger=None,
         contact_config=None,
+        flavor=None,
         ac_ports=None,
         reference_node=None,
         nodes=None,
         inp_name=None,
+        va_code_filter=None,
     ):
         self._copy_va_files = copy_va_files
         # files to be copied into simulation directory
@@ -166,7 +170,7 @@ class DutView(object):
             else:
                 self.list_copy = list_copy
 
-        self._list_va_file_contents = []
+        self._list_va_file_contents: list[VAFile] = []
 
         # attributes for data management
         self._separate_databases = separate_databases
@@ -175,9 +179,9 @@ class DutView(object):
             self._database_dir = DATA_CONFIG["directories"]["database"]
         else:
             if isinstance(database_dir, Path):
-                self._database_dir = database_dir.expanduser()
+                self._database_dir = database_dir.expanduser().resolve()
             else:
-                self._database_dir = Path(database_dir).expanduser()
+                self._database_dir = Path(database_dir).expanduser().resolve()
 
         self.dut_type = dut_type
 
@@ -206,6 +210,7 @@ class DutView(object):
         # simulation attributes
         self.inp_name = inp_name
         self.sim_command = simulator_command
+        self.va_code_filter = va_code_filter
 
         if simulator_arguments is None:
             self.sim_args = []
@@ -229,17 +234,20 @@ class DutView(object):
 
         self.technology = technology
         self.contact_config = contact_config
+        self.flavor = flavor
         self.width = width
         self.length = length
         self.nfinger = nfinger
-        if (
-            (width is not None)
-            and (length is not None)
-            and (not isinstance(length, tuple) and (not isinstance(width, tuple)))
-        ):
-            self.perimeter = (self.width + self.length) * 2
-            self.area = self.width * self.length
-        else:
+        try:
+            # if ( # was
+            #     (width is not None)
+            #     and (length is not None)
+            #     and (not isinstance(length, tuple) and (not isinstance(width, tuple)))
+            # ):
+            self.perimeter = (self.width + self.length) * 2  # type: ignore
+            self.area = self.width * self.length  # type: ignore
+        except TypeError:
+            # else:
             self.perimeter = None
             self.area = None
 
@@ -259,7 +267,7 @@ class DutView(object):
         """Creates a simulation folder, appends the sweep to the structure definition and creates a input file in the simulation folder.
 
         Parameters
-        -----------
+        ----------
         sweep : Sweep
         """
         logging.info(
@@ -272,9 +280,6 @@ class DutView(object):
         sim_folder = self.get_sim_folder(sweep)
 
         inp_content = self.make_input(sweep)
-        pbs = DATA_CONFIG["server"]["use_pbs"] and DATA_CONFIG["backend_remote"]
-        if pbs:
-            pbs_content = self.make_pbs(sweep)  # needs to be implemented by the DUT
 
         try:
             sim_folder.mkdir(parents=True)
@@ -289,14 +294,22 @@ class DutView(object):
                 )
 
         (sim_folder / self.inp_name).write_text(inp_content)
-        if pbs:
+        if DATA_CONFIG["server"]["use_pbs"] and DATA_CONFIG["backend_remote"]:
+            pbs_content = self.make_pbs(sweep)  # needs to be implemented by the DUT
             (sim_folder / "pbs_job").write_text(pbs_content)
 
         # copy va files?
         sim_folder = self.get_sim_folder(sweep)
         if self._copy_va_files:
-            for (va_file, va_file_content) in self._list_va_file_contents:
-                (sim_folder / va_file).write_text(va_file_content)
+            for vafile in self._list_va_file_contents:
+                vafile.write_files(sim_folder, filter=self.va_code_filter)
+        else:
+            # write the files into a separate folder in simulations/va_files/HASH/
+            va_files_dir = self.sim_dir / "VA_codes"
+            for vafile in self._list_va_file_contents:
+                dir_code = va_files_dir / vafile.get_tree_hash()
+                if not dir_code.is_dir():
+                    vafile.write_files(dir_code, filter=self.va_code_filter)
 
         for data_copy in self.list_copy:
             try:
@@ -320,7 +333,7 @@ class DutView(object):
         """Returns the command to start the simulation
 
         Returns
-        --------
+        -------
         str
         """
         return self.sim_command + " " + " ".join(self.sim_args) + " " + self.inp_name
@@ -347,7 +360,7 @@ class DutView(object):
         """Return a unique hash for this Dut without (!) considering the Sweep.
 
         Returns
-        ----------
+        -------
         hash : float64
             Hash that corresponds to this DUT.
         """
@@ -364,7 +377,7 @@ class DutView(object):
             If True, the simulation folder is deleted after reading.
 
         Raises
-        -------
+        ------
         NotImplementedError
             If the Dut is not a simulatable dut.
         IOError
@@ -383,7 +396,7 @@ class DutView(object):
             Sweep that has been simulated.
 
         Raises
-        --------
+        ------
         NotImplementedError
             If the Dut is not a simulatable dut.
         SimulationUnsuccessful
@@ -444,7 +457,7 @@ class DutView(object):
             Sweep object that corresponds to the folder.
 
         Returns
-        --------
+        -------
         str
             Path to the simulationfolder
         """
@@ -601,10 +614,11 @@ class DutView(object):
     def get_data(self, key="iv", sweep=None):
         """Return data stored in the DutView's data.
 
-        | One needs to specify either:
-        | - key      : The data stored under the path key in the dut's database is returned.
-        | - sweep    : Get the data from this sweep. If none, key must be a valid key for the database.
-        | - sweep+key: Return the data stored as self.get_sweep_key(sweep)+'/'+key from the dut's database.
+        One needs to specify either:
+
+        - key      : The data stored under the path key in the dut's database is returned.
+        - sweep    : Get the data from this sweep. If none, key must be a valid key for the database.
+        - sweep+key: Return the data stored as self.get_sweep_key(sweep)+'/'+key from the dut's database.
 
         Parameters
         ----------
@@ -721,7 +735,7 @@ class DutView(object):
         if separate databases is activated it loads only the given sweep (and it has to be given then!)
 
         Parameters
-        -------------
+        ----------
         sweep : Sweep or str, optional
             In case of separate databases, the sweep must be given either directly or as string name
         """
@@ -774,11 +788,11 @@ class DutView(object):
         """Joins the parts of the key into one key for self.dict
 
         Parameters
-        -----------
+        ----------
         parts_key : iterable
 
         Returns
-        --------
+        -------
         str
             parts_key[0]/parts_key[1]/.../parts_key[-1]
         """
@@ -788,11 +802,11 @@ class DutView(object):
         """Splits the key up in its parts.
 
         Parameters
-        -----------
+        ----------
         key : str
 
         Returns
-        --------
+        -------
         list[str]
             key splitted at '/'
 
@@ -803,12 +817,12 @@ class DutView(object):
         """Key for the dict in dut.data.
 
         Parameters
-        ------------
+        ----------
         sweep : :class:`~DMT.core.sweep.Sweep` or str
             Either the key for the given sweep or if it is a string, directly the string
 
         Returns
-        ---------
+        -------
         key : str
         """
         try:
@@ -827,7 +841,7 @@ class DutView(object):
         * Range of temperatures: "T[xxx.xx-sss.ss-yyy.yy]K", s is the step
 
         Parameters
-        ------------
+        ----------
         key : str
             Key that shall be evaluated.
 
