@@ -151,7 +151,7 @@ class McParameter(object):
 
         if not isinstance(name, str):
             raise IOError("DMT -> McParameter: Parameter name not a string.")
-        self.name = name
+        self.name = name.lower()  # always lower case...
         self.inc_min = inc_min
         self.inc_max = inc_max
         if value_type == int:
@@ -561,6 +561,7 @@ class McParameter(object):
                 return "-"  # dirty
 
             return f"{self.value:{wanted_format}}"
+
         if "g" in wanted_format:
             if self.value is None:
                 return "-"  # dirty
@@ -569,7 +570,8 @@ class McParameter(object):
                 return f"{self.value:{wanted_format}}"
             else:
                 # 10.5g -> 10d
-                wanted_format = wanted_format.split(".")[0] + "d"
+                wanted_format = wanted_format.replace("g", "d")
+
                 return f"{self.value:{wanted_format}}"
 
         if "s" in wanted_format:
@@ -625,7 +627,7 @@ class McParameterCollection(object):
         __McParameterCollection__: Union[
             VersionInfo, str, float
         ] = SEMVER_MCPARAMETER_Collection_CURRENT,
-        **_kwargs,
+        **kwargs,
     ):
         if not isinstance(__McParameterCollection__, VersionInfo):
             try:
@@ -648,6 +650,12 @@ class McParameterCollection(object):
         else:
             self.possible_groups = possible_groups
 
+        for key in kwargs:
+            warnings.warn(
+                f"{type(self)} was created with the remaining kwarg {key}={kwargs[key]}",
+                category=RuntimeWarning,
+            )
+
     @property
     def paras(self):
         """Return the parameters with updated values."""
@@ -794,9 +802,9 @@ class McParameterCollection(object):
 
         try:
             if isinstance(parameters, McParameter):
-                my_para = next(para for para in self._paras if para.name == parameters.name)
+                my_para = next(para for para in self._paras if para.name == parameters.name.lower())
             elif isinstance(parameters, str):
-                my_para = next(para for para in self._paras if para.name == parameters)
+                my_para = next(para for para in self._paras if para.name == parameters.lower())
             else:
                 raise IOError("The parameter is neither of type McParameter or str.")
 
@@ -876,6 +884,7 @@ class McParameterCollection(object):
             If the para was not in self.
         """
         for name, value in dict_parameters.items():
+            name = name.lower()
             try:
                 index = self.name.index(name)
             except ValueError as err:
@@ -920,7 +929,7 @@ class McParameterCollection(object):
         """
         values = {}
         for name in parameters:
-            values[name] = self._values[name]
+            values[name] = self._values[name.lower()]
 
         return values
 
@@ -939,7 +948,7 @@ class McParameterCollection(object):
         """
         for name, values in dict_parameters.items():
             try:
-                index = self.name.index(name)
+                index = self.name.index(name.lower())
             except ValueError as err:
                 raise KeyError(
                     f"The parameter {name:s} is not part of this parameter collection!"
@@ -1164,7 +1173,7 @@ class McParameterCollection(object):
         for para, max_a in zip(self._paras, max_new):
             para.max = max_a
 
-    def print_tex(self):
+    def print_tex(self, pretext="The final modelcard is summarized in the table below:"):
         """Prints a modelcard as a tex table using PyLaTeX"""
         # try to clean first
         try:
@@ -1179,22 +1188,22 @@ class McParameterCollection(object):
         doc = Tex()
         # Generate data table
         with doc.create(Section("Modelcard")):
-            doc.append("The final modelcard is summarized in the table below:")
+            doc.append(pretext)
             with doc.create(
-                LongTable("l S s", width=3, booktabs=True)
+                LongTable(NoEscape(r"l S"), width=2, booktabs=True)
             ) as data_table:  # pylatex does not count s S columns from siunitx
                 data_table.add_hline()
-                data_table.add_row(["parameter name", NoEscape("{value}"), NoEscape("{unit}")])
+                data_table.add_row(["parameter", NoEscape("{value}")])
                 data_table.add_hline()
                 data_table.end_table_header()
                 data_table.add_hline()
                 data_table.add_row(
-                    (MultiColumn(3, align="r", data="continued on next Page"),), strict=False
+                    (MultiColumn(2, align="r", data="continued on next Page"),), strict=False
                 )
                 data_table.add_hline()
                 data_table.end_table_footer()
                 data_table.add_hline()
-                data_table.add_row((MultiColumn(3, align="r", data="Finish"),), strict=False)
+                data_table.add_row((MultiColumn(2, align="r", data="Finish"),), strict=False)
                 data_table.add_hline()
                 data_table.end_table_last_footer()
 
@@ -1212,14 +1221,27 @@ class McParameterCollection(object):
                                 if group_a == group
                             )
                             data_table.add_row(
-                                (MultiColumn(3, align="l", data=group_desc),), strict=False
+                                (MultiColumn(2, align="l", data=group_desc),), strict=False
                             )
                         except StopIteration:
                             pass
 
-                    data_table.add_row(
-                        [f"{para:<12s}", NoEscape(f"{para:g}"), NoEscape(f"{para:u}")], strict=False
-                    )
+                    if para.unit.dimensionless:
+                        data_table.add_row(
+                            [
+                                NoEscape(f"{para:<12s}"),
+                                NoEscape(f"{para:g}"),
+                            ],
+                            strict=False,
+                        )
+                    else:
+                        data_table.add_row(
+                            [
+                                NoEscape(f"{para:<12s}/\si{{{para:u}}}"),
+                                NoEscape(f"{para:g}"),
+                            ],
+                            strict=False,
+                        )
 
         return doc
 
