@@ -91,7 +91,7 @@ unit_converter = {
     "": unit_registry.dimensionless,
 }
 
-SEMVER_MCARD_CURRENT = VersionInfo(major=2, minor=1)
+SEMVER_MCARD_CURRENT = VersionInfo(major=2, minor=2)
 
 
 class MCard(McParameterCollection):
@@ -149,6 +149,8 @@ class MCard(McParameterCollection):
         directory_va_file: Optional[Union[str, os.PathLike]] = None,
         __MCard__=SEMVER_MCARD_CURRENT,
         ignore_checksum: bool = False,
+        pdk_path: str = "",
+        pdk_corner: str = "",
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -200,6 +202,8 @@ class MCard(McParameterCollection):
         self.default_subckt_name = default_subckt_name
         self.default_module_name = default_module_name
         self.version = version
+        self.pdk_path = pdk_path
+        self.pdk_corner = pdk_corner
 
         self._va_codes = None
         if va_codes is not None:
@@ -551,6 +555,8 @@ class MCard(McParameterCollection):
         info_dict["default_subckt_name"] = self.default_subckt_name
         info_dict["default_module_name"] = self.default_module_name
         info_dict["version"] = self.version
+        info_dict["pdk_path"] = self.pdk_path
+        info_dict["pdk_corner"] = self.pdk_corner
 
         if save_va_code and self.va_codes is not None:
             info_dict["va_codes"] = self.va_codes.export_dict(compressed_code=compress_va_code)
@@ -779,6 +785,11 @@ class MCard(McParameterCollection):
                     self.add(McParameter(parameter_name, value=parameter_value))
                 except ValueError:
                     # if force==False and parameter value is out of bounds -> do not set the value...
+                    warnings.warn(
+                        f"DMT->MCard: The parameter {parameter_name} was not loaded from {path_to_file} since the value {parameter_value} was out of bounds.",
+                        category=RuntimeWarning,
+                    )
+
                     logging.info(
                         "DMT->MCard: The parameter %s was not loaded from %s since the value %f was out of bounds.",
                         parameter_name,
@@ -803,6 +814,19 @@ class MCard(McParameterCollection):
                         self.set_values({parameter_name: parameter_value}, force=force)
                     except KeyError:
                         self.add(McParameter(parameter_name, value=parameter_value))
+                    except ValueError:
+                        # if force==False and parameter value is out of bounds -> do not set the value...
+                        warnings.warn(
+                            f"DMT->MCard: The parameter {parameter_name} was not loaded from {path_to_file} since the value {parameter_value} was out of bounds.",
+                            category=RuntimeWarning,
+                        )
+
+                        logging.info(
+                            "DMT->MCard: The parameter %s was not loaded from %s since the value %f was out of bounds.",
+                            parameter_name,
+                            path_to_file,
+                            parameter_value,
+                        )
         else:
             raise OSError(
                 "Loading from file worked, but I do not know how to handle the loaded content of type "
@@ -848,6 +872,9 @@ class Calculator(ast.NodeVisitor):
     def visit_Num(self, node):
         return node.n
 
+    def visit_Constant(self, node):
+        return node.n
+
     def visit_Expr(self, node):
         return self.visit(node.value)
 
